==> dl.php?src=linea21_1_7.zip: linea21/news/help.php <==
<?php
/**
 * @package linea21.modules
 * @subpackage news
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')) {
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

//////////// Check Droits utilisateur ////////////
if (!$l21auth->hasRight('news')) ReloadIndex('admin');
////////////

$dirbox = $dir . "/help";
?>
<br class="brendstep brendstepfooter" />
<div class="headerhelp">
<div class="help">
<a href="#aide-ancre" class="aide-ancre" id="aide-ancre" title="<?php echo _t('help','title');?>"><i class="icon-lifebuoy"></i> <?php echo _t('help','title');?></a>

<div id="aide"><?php if ($todo == 'add') {
  ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('news','add');?></p>
<ul>
	<li><?php echo _t('news','help_add1');?></li>
	<li><?php echo _t('news','help_add2');?></li>
	<li><?php echo _t('news','help_add3');?></li>
</ul>

  <?php }
  if ($todo == 'det') {
  ?>
    <p class="info"><?php echo _t('help','name');?> : <?php echo _t('news','det');?></p>
    <ul>
    	<li><?php echo _t('news','help_det1');?></li>
    	<li><?php echo _t('news','help_det2');?></li>
    </ul>
  <?php
  }
  if ($todo == 'mod') {
    ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('news','mod');?></p>
<ul>
	<li><?php echo _t('news','help_mod1');?></li>
	<li><?php echo _t('news','help_mod2');?></li>
	<li><?php echo _t('news','help_mod3');?></li>
</ul>
    <?php }
    if ($todo == 'list') {
      ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('news','list');?></p>
<ul>
	<li><?php echo _t('news','help_list1');?></li>
	<li><?php echo _t('news','help_list2');?></li>
	<li><?php echo _t('news','help_list3');?></li>
	<li><?php echo _t('news','help_list4');?></li>
	<li><?php echo _t('news','help_list5');?></li>
</ul>
      <?php }
      if ($todo == 'sup') {
        ?>

<p class="info"><?php echo _t('help','name');?> : <?php echo _t('news','sup');?></p>
<ul>
	<li><?php echo _t('news','help_sup1');?></li>
</ul>
        <?php }
include_once(THEME_ADMIN_PATH."footer_content.php");
?>

==> dl.php?src=linea21_1_8.zip: linea21/news/help.php <==
<?php
/**
 * News module
 * 
 * Provide an online help related to current module
 * 
 * @package linea21\modules\news
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')) {
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

//////////// Check Droits utilisateur ////////////
if (!$l21auth->hasRight('news')) ReloadIndex('admin');
////////////
?>
<div class="headerhelp">
<div class="help">
<a href="#aide-ancre" class="aide-ancre" id="aide-ancre" title="<?php echo _t('help','title');?>"><i class="icon-lifebuoy"></i> <?php echo _t('help','title');?></a>

<div id="aide"><?php if ($todo == 'add') {
  ?>
<p class="info"><?php echo _t('help','name'); ?> : <?php echo _t('news','add');?></p>
<ul>
	<li><?php echo _t('news','help_add1');?></li>
	<li><?php echo _t('news','help_add2');?></li>
	<li><?php echo _t('news','help_add3');?></li>
</ul>

  <?php }
  if ($todo == 'det') {
  ?>
    <p class="info"><?php echo _t('help','name');?> : <?php echo _t('news','det');?></p>
    <ul>
    	<li><?php echo _t('news','help_det1');?></li>
    	<li><?php echo _t('news','help_det2');?></li>
    </ul>
  <?php
  }
  if ($todo == 'mod') {
    ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('news','mod');?></p>
<ul>
	<li><?php echo _t('news','help_mod1');?></li>
	<li><?php echo _t('news','help_mod2');?></li>
	<li><?php echo _t('news','help_mod3');?></li>
</ul>
    <?php }
    if ($todo == 'list') {
      ?>
<p class="info"><?php echo _t('help','name');?> : <?php echo _t('news','list');?></p>
<ul>
	<li><?php echo _t('news','help_list1');?></li>
	<li><?php echo _t('news','help_list2');?></li>
	<li><?php echo _t('news','help_list3');?></li>
	<li><?php echo _t('news','help_list4');?></li>
	<li><?php echo _t('news','help_list5');?></li>
</ul>
      <?php }
      if ($todo == 'sup') {
        ?>

<p class="info"><?php echo _t('help','name'); ?> : <?php echo _t('news','sup');?> </p>
<ul>
	<li><?php echo _t('news','help_sup1');?></li>
</ul>
<?php } ?>
</div> <!-- closing #aide -->
</div> <!-- closing .help -->
</div> <!-- closing ."headerhelp" -->
